@@ -15,7 +15,10 @@
 const char* FILE_NAME = "Sys/Socket/Ip_mreq_source.c";
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__new(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
+#ifdef __OpenBSD__
+  env->die(env, stack, "The new method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+#else
   int32_t e = 0;
   
   struct ip_mreq_source* multi_request_source = env->new_memory_stack(env, stack, sizeof(struct ip_mreq_source));
@@ -26,11 +29,15 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__new(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].oval = obj_multi_request_source;
   
   return 0;
+#endif
 }
 
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
+#ifdef __OpenBSD__
+  env->die(env, stack, "The new method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+#else
   void* obj_multi_request_source = stack[0].oval;
   
   struct ip_mreq_source* multi_request_source = env->get_pointer(env, stack, obj_multi_request_source);
@@ -41,10 +48,14 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__DESTROY(SPVM_ENV* env, SPVM_VALUE* st
   env->set_pointer(env, stack, obj_multi_request_source, NULL);
   
   return 0;
+#endif
 }
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_multiaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
+#ifdef __OpenBSD__
+  env->die(env, stack, "The new method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+#else
   int32_t e = 0;
   
   void* obj_self = stack[0].oval;
@@ -62,10 +73,14 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_multiaddr(SPVM_ENV* env, SPVM_VAL
   stack[0].oval = obj_address_ret;
   
   return 0;
+#endif
 }
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_multiaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
+#ifdef __OpenBSD__
+  env->die(env, stack, "The set_imr_multiaddr method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+#else
   void* obj_self = stack[0].oval;
   
   struct ip_mreq_source* multi_request_source = env->get_pointer(env, stack, obj_self);
@@ -76,10 +91,14 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_multiaddr(SPVM_ENV* env, SPVM
   multi_request_source->imr_multiaddr = *address;
   
   return 0;
+#endif
 }
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_interface(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
+#ifdef __OpenBSD__
+  env->die(env, stack, "The imr_interface method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+#else
   int32_t e = 0;
   
   void* obj_self = stack[0].oval;
@@ -97,10 +116,14 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_interface(SPVM_ENV* env, SPVM_VAL
   stack[0].oval = obj_address_ret;
   
   return 0;
+#endif
 }
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_interface(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
+#ifdef __OpenBSD__
+  env->die(env, stack, "The set_imr_interface method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+#else
   void* obj_self = stack[0].oval;
   
   struct ip_mreq_source* multi_request_source = env->get_pointer(env, stack, obj_self);
@@ -111,10 +134,14 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_interface(SPVM_ENV* env, SPVM
   multi_request_source->imr_interface = *address;
   
   return 0;
+#endif
 }
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_sourceaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
+#ifdef __OpenBSD__
+  env->die(env, stack, "The imr_sourceaddr method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+#else
   int32_t e = 0;
   
   void* obj_self = stack[0].oval;
@@ -132,10 +159,14 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_sourceaddr(SPVM_ENV* env, SPVM_VA
   stack[0].oval = obj_address_ret;
   
   return 0;
+#endif
 }
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_sourceaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
+#ifdef __OpenBSD__
+  env->die(env, stack, "The set_imr_sourceaddr method in the Sys::Socket::Ip_mreq_sourceclock_nanosleep is not supported on this system(__OpenBSD__)", FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+#else
   void* obj_self = stack[0].oval;
   
   struct ip_mreq_source* multi_request_source = env->get_pointer(env, stack, obj_self);
@@ -146,4 +177,5 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_sourceaddr(SPVM_ENV* env, SPV
   multi_request_source->imr_sourceaddr = *address;
   
   return 0;
+#endif
 }
